// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using System.Linq;
using System.Collections.Generic;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Svg;
using GCTEXT = GrapeCity.Documents.Text;
using GCDRAW = GrapeCity.Documents.Drawing;
using DsPdfWeb.Demos.Common;

namespace DsPdfWeb.Demos
{
    // GcSvgDocument を使用して、https://www.w3.org/TR/SVG2/Overview.htmlでイラストとして使用されている
    // いくつかの画像をレンダリングします。
    public class SvgSpecArt
    {
        public int CreatePDF(Stream stream)
        {
            //リソースから画像を読み込みます。
            var fnames = new List<string>() { "dash-path.svg", "opacity.svg", "paths.svg", "shadowstyle.svg", "units.svg", };
            var images = new List<(string, GcSvgDocument)>();
            foreach (var f in fnames)
                images.Add((f, GcSvgDocument.FromFile(Path.Combine("Resources", "SvgSpecArt", f))));

            const float margin = 36;
            const float gapy = 18;
            var ip = new PointF(margin, margin);

            // 画像をレンダリングします。
            var doc = new GcPdfDocument();
            var g = doc.NewPage().Graphics;
            for (int i = 0; i < images.Count(); ++i)
            {
                var svg = images[i].Item2;
                var s = svg.GetIntrinsicSize(SvgLengthUnits.Points);
                g.DrawSvg(svg, ip);
                ip.Y += s.Height + gapy;
            }
            // PDF ドキュメントを保存します。
            doc.Save(stream);
            // PDF 保存後に画像を破棄します。
            images.ForEach(t_ => t_.Item2.Dispose());
            return doc.Pages.Count;
        }
    }
}
